DiagMut

Type Alias DiagMut 

pub type DiagMut<'a, T, Dim = usize, Stride = isize> = Diag<Mut<'a, T, Dim, Stride>>;
diagonal mutable matrix view

Aliased Type

#[repr(transparent)]
pub struct DiagMut<'a, T, Dim = usize, Stride = isize>(pub Mut<'a, T, Dim, Stride>);

Tuple Fields

0: Mut<'a, T, Dim, Stride>

Implementations

Source

impl<'a, T> DiagMut<'a, T>

pub fn from_mut(value: &'a mut T) -> Self

creates a diagonal matrix view over the given element

pub fn from_slice_mut(slice: &'a mut [T]) -> Self

creates a DiagMut from slice views over the diagonal data, the result has the same dimension as the length of the input slice

Source

impl<'a, T, Dim: Shape, Stride: Stride> DiagMut<'a, T, Dim, Stride>

pub const unsafe fn from_raw_parts_mut( ptr: *mut T, dim: Dim, stride: Stride, ) -> Self

creates a DiagMut from pointers to the diagonal data, dimension, and stride

safety

this function has the same safety requirements as [MatMut::from_raw_parts_mut(ptr, dim, 1, stride, 0)]

pub fn column_vector(self) -> ColRef<'a, T, Dim, Stride>

returns the diagonal as a column vector view

pub fn column_vector_mut(self) -> ColMut<'a, T, Dim, Stride>

returns the diagonal as a mutable column vector view

pub fn as_ref(&self) -> DiagRef<'_, T, Dim, Stride>

returns a view over self

pub fn as_mut(&mut self) -> DiagMut<'_, T, Dim, Stride>

returns a view over self

pub fn fill(&mut self, value: T)
where T: Clone,

fills all the elements of self with value

pub fn as_shape<D: Shape>(self, len: D) -> DiagRef<'a, T, D, Stride>

pub fn as_dyn(self) -> DiagRef<'a, T, usize, Stride>

pub fn as_dyn_stride(self) -> DiagRef<'a, T, Dim>

pub fn conjugate(self) -> DiagRef<'a, T::Conj, Dim, Stride>
where T: Conjugate,

pub fn canonical(self) -> DiagRef<'a, T::Canonical, Dim, Stride>
where T: Conjugate,

pub fn as_shape_mut<D: Shape>(self, len: D) -> DiagMut<'a, T, D, Stride>

pub fn as_dyn_mut(self) -> DiagMut<'a, T, usize, Stride>

pub fn as_dyn_stride_mut(self) -> DiagMut<'a, T, Dim>

pub fn conjugate_mut(self) -> DiagMut<'a, T::Conj, Dim, Stride>
where T: Conjugate,

pub fn canonical_mut(self) -> DiagMut<'a, T::Canonical, Dim, Stride>
where T: Conjugate,

pub fn dim(&self) -> Dim

returns the dimension of self

pub fn copy_from<RhsT: Conjugate<Canonical = T>>( &mut self, rhs: impl AsDiagRef<T = RhsT, Dim = Dim>, )
where T: ComplexField,

copies other into self